# Manifestoo Core

```{include} ../README.md
:start-after: <!--- shortdesc-begin -->
:end-before: <!--- shortdesc-end -->
```

```{toctree}
:hidden:
:maxdepth: 2

installation
api
Development <develop>
Changelog <changelog>
GitHub Repository <https://github.com/acsone/manifestoo-core>
```

```{include} ../README.md
:start-after: <!--- features-begin -->
:end-before: <!--- features-end -->
```
